History
=======

27.01.2012
----------

- ``iters.accumulate`` - backported version for Python < 3.3
- first implementation for ``monad.Option`` with tests and README samples

23.01.2012
----------

- ``fn.Stream`` slice is another ``fn.Stream``
- ``fn.Stream`` got new public method ``cursor`` to get position on next evaluated element

21.01.2012
----------

- Update documentation with special ``fn._`` use cases for interactive shells
- Move ``zipwith`` from ``fn.iters`` to ``fn.op``
- ``fn._`` dump to string

18.01.2012
----------

-  Added 22 itertools recipes to ``fn.iters``
-  Documentation is converted to RST

17.01.2012
----------

-  Unit tests coverage for ``fn.stream.Stream``
-  ``_StreamIterator`` works fine both in Python 2/3

16.01.2012
----------

-  Finished underscore module functionality
-  Test cases for all implemented modules/functions
-  Update in Readme file with several fixes
-  Get rid of F.flip classmethod in pref. for simple building blocks
-  Optimized version for fn.op.flip operator

14.01.2012
----------

-  Simplest ``Stream`` implementation
-  Code samples for streams, labdas (``_``) and functions compositions
-  Plan, contribute section in readme file

13.01.2012
----------

-  Full list of ideas on paper
-  Repository is created
-  Initial commit
